@@ -39,18 +39,18 @@ Q_OBJECT
 
 public:
     kpToolFloodFill (kpToolEnvironment *environ, QObject *parent);
-    virtual ~kpToolFloodFill ();
+    ~kpToolFloodFill () override;
 
 private:
     QString haventBegunDrawUserMessage () const;
 
 public:
-    virtual void begin ();
-    virtual void beginDraw ();
-    virtual void draw (const QPoint &thisPoint, const QPoint &, const QRect &);
-    virtual void cancelShape ();
-    virtual void releasedAllButtons ();
-    virtual void endDraw (const QPoint &, const QRect &);
+    void begin () override;
+    void beginDraw () override;
+    void draw (const QPoint &thisPoint, const QPoint &, const QRect &) override;
+    void cancelShape () override;
+    void releasedAllButtons () override;
+    void endDraw (const QPoint &, const QRect &) override;
 
 private:
     struct kpToolFloodFillPrivate * const d;
